0.9.9 API documentation: GLM_GTX_mixed_producte

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_mixed_producte
Experimental extensions

Include <glm/gtx/mixed_product.hpp> to use the features of this extension. More...

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL T | mixedProduct (vec< 3, T, Q > const &v1, vec< 3, T, Q > const &v2, vec< 3, T, Q > const &v3)
| Mixed product of 3 vectors (from GLM_GTX_mixed_product extension)

## Detailed Description

Include <glm/gtx/mixed_product.hpp> to use the features of this extension.

Mixed product of 3 vectors.